@@ -7,9 +7,9 @@
 
 #include "messageflags.h"
 
-#include <item.h>
-#include <kmime/kmime_message.h>
-#include <kmime/kmime_util.h>
+#include <Akonadi/Item>
+#include <KMime/KMimeMessage>
+#include <KMime/Util>
 
 const char Akonadi::MessageFlags::Seen[] = "\\SEEN";
 const char Akonadi::MessageFlags::Deleted[] = "\\DELETED";
