@@ -6,13 +6,13 @@
 
 #include "foldersrequester.h"
 
-#include <QDebug>
-#include <KLocalizedString>
+#include <Akonadi/Collection>
+#include <Akonadi/Control>
 #include <KAboutData>
+#include <KLocalizedString>
 #include <QApplication>
 #include <QCommandLineParser>
-#include <collection.h>
-#include <control.h>
+#include <QDebug>
 #include <specialmailcollections.h>
 #include <specialmailcollectionsrequestjob.h>
 
@@ -22,7 +22,7 @@ Requester::Requester()
 {
     Control::start();
 
-    auto *rjob = new SpecialMailCollectionsRequestJob(this);
+    auto rjob = new SpecialMailCollectionsRequestJob(this);
     rjob->requestDefaultCollection(SpecialMailCollections::Outbox);
     connect(rjob, &SpecialMailCollectionsRequestJob::result, this, &Requester::requestResult);
     rjob->start();
@@ -43,8 +43,7 @@ int main(int argc, char **argv)
 {
     QCommandLineParser parser;
 
-    KAboutData about(QStringLiteral("foldersrequester"),
-                     i18n("An app that requests LocalFolders"), QStringLiteral("0.1"));
+    KAboutData about(QStringLiteral("foldersrequester"), i18n("An app that requests LocalFolders"), QStringLiteral("0.1"));
 
     about.setupCommandLine(&parser);
     KAboutData::setApplicationData(about);
